==> pegasus-merchandise-api-3.3.4-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuAuditRecordsVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class PcsSkuAuditRecordsVO implements Serializable {

  private static final long serialVersionUID = -6102484193492936717L;

  private Integer id;

  private String skuCode;

  private Date submitReviewTime;

  private BigDecimal newAverageLogisticsCosts;

  private BigDecimal newSalePrice;

  private BigDecimal newCostPrice;

  private Integer changeStatus;

  private String newNameCn;

  private Integer newBrandId;

  private String newWeight;

  private BigDecimal newNetWeight;

  private String newMaterial;

  private String newSpecification;

  private String newPurpose;

  private String newPlaceoforigin;

  private BigDecimal newExchangeCostPrice;

  private Long newSupplierId;

  private Integer newSkuType;

  private Long submitUserId;

  private BigDecimal newClearanceFee;
  private BigDecimal newTariff;

  private Integer newCategoryId;
  private String newCategoryFullName;
  private String newBu;
  private Integer newIsOwnImported;
  private Integer newCrossBorderFlag;
  private Integer newClearanceWay;
  private Boolean canWithdraw;
  private Integer preSubmitStatus;

  public String getSkuCode() {
    return skuCode;
  }

  public void setSkuCode(String skuCode) {
    this.skuCode = skuCode;
  }

  public Date getSubmitReviewTime() {
    return submitReviewTime;
  }

  public void setSubmitReviewTime(Date submitReviewTime) {
    this.submitReviewTime = submitReviewTime;
  }

  public BigDecimal getNewAverageLogisticsCosts() {
    return newAverageLogisticsCosts;
  }

  public void setNewAverageLogisticsCosts(BigDecimal newAverageLogisticsCosts) {
    this.newAverageLogisticsCosts = newAverageLogisticsCosts;
  }

  public BigDecimal getNewSalePrice() {
    return newSalePrice;
  }

  public void setNewSalePrice(BigDecimal newSalePrice) {
    this.newSalePrice = newSalePrice;
  }

  public BigDecimal getNewCostPrice() {
    return newCostPrice;
  }

  public void setNewCostPrice(BigDecimal newCostPrice) {
    this.newCostPrice = newCostPrice;
  }

  public Integer getChangeStatus() {
    return changeStatus;
  }

  public void setChangeStatus(Integer changeStatus) {
    this.changeStatus = changeStatus;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public String getNewNameCn() {
    return newNameCn;
  }

  public void setNewNameCn(String newNameCn) {
    this.newNameCn = newNameCn;
  }

  public Integer getNewBrandId() {
    return newBrandId;
  }

  public void setNewBrandId(Integer newBrandId) {
    this.newBrandId = newBrandId;
  }

  public String getNewWeight() {
    return newWeight;
  }

  public void setNewWeight(String newWeight) {
    this.newWeight = newWeight;
  }

  public BigDecimal getNewNetWeight() {
    return newNetWeight;
  }

  public void setNewNetWeight(BigDecimal newNetWeight) {
    this.newNetWeight = newNetWeight;
  }

  public String getNewMaterial() {
    return newMaterial;
  }

  public void setNewMaterial(String newMaterial) {
    this.newMaterial = newMaterial;
  }

  public String getNewSpecification() {
    return newSpecification;
  }

  public void setNewSpecification(String newSpecification) {
    this.newSpecification = newSpecification;
  }

  public String getNewPurpose() {
    return newPurpose;
  }

  public void setNewPurpose(String newPurpose) {
    this.newPurpose = newPurpose;
  }

  public String getNewPlaceoforigin() {
    return newPlaceoforigin;
  }

  public void setNewPlaceoforigin(String newPlaceoforigin) {
    this.newPlaceoforigin = newPlaceoforigin;
  }

  public BigDecimal getNewExchangeCostPrice() {
    return newExchangeCostPrice;
  }

  public void setNewExchangeCostPrice(BigDecimal newExchangeCostPrice) {
    this.newExchangeCostPrice = newExchangeCostPrice;
  }

  public Long getNewSupplierId() {
    return newSupplierId;
  }

  public void setNewSupplierId(Long newSupplierId) {
    this.newSupplierId = newSupplierId;
  }

  public Integer getNewSkuType() {
    return newSkuType;
  }

  public void setNewSkuType(Integer newSkuType) {
    this.newSkuType = newSkuType;
  }

  public Long getSubmitUserId() {
    return submitUserId;
  }

  public void setSubmitUserId(Long submitUserId) {
    this.submitUserId = submitUserId;
  }

  public BigDecimal getNewClearanceFee() {
    return newClearanceFee;
  }

  public void setNewClearanceFee(BigDecimal newClearanceFee) {
    this.newClearanceFee = newClearanceFee;
  }

  public BigDecimal getNewTariff() {
    return newTariff;
  }

  public void setNewTariff(BigDecimal newTariff) {
    this.newTariff = newTariff;
  }

  public Integer getNewCategoryId() {
    return newCategoryId;
  }

  public void setNewCategoryId(Integer newCategoryId) {
    this.newCategoryId = newCategoryId;
  }

  public String getNewBu() {
    return newBu;
  }

  public void setNewBu(String newBu) {
    this.newBu = newBu;
  }

  public Integer getNewIsOwnImported() {
    return newIsOwnImported;
  }

  public void setNewIsOwnImported(Integer newIsOwnImported) {
    this.newIsOwnImported = newIsOwnImported;
  }

  public Integer getNewCrossBorderFlag() {
    return newCrossBorderFlag;
  }

  public void setNewCrossBorderFlag(Integer newCrossBorderFlag) {
    this.newCrossBorderFlag = newCrossBorderFlag;
  }

  public Integer getNewClearanceWay() {
    return newClearanceWay;
  }

  public void setNewClearanceWay(Integer newClearanceWay) {
    this.newClearanceWay = newClearanceWay;
  }

  public Boolean getCanWithdraw() {
    return canWithdraw;
  }

  public void setCanWithdraw(Boolean canWithdraw) {
    this.canWithdraw = canWithdraw;
  }

  public Integer getPreSubmitStatus() {
    return preSubmitStatus;
  }

  public void setPreSubmitStatus(Integer preSubmitStatus) {
    this.preSubmitStatus = preSubmitStatus;
  }

    public String getNewCategoryFullName() {
        return newCategoryFullName;
    }

    public void setNewCategoryFullName(String newCategoryFullName) {
        this.newCategoryFullName = newCategoryFullName;
    }
}

==> pegasus-merchandise-api-3.8.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuAuditRecordsVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class PcsSkuAuditRecordsVO implements Serializable {

  private static final long serialVersionUID = -6102484193492936717L;

  private Integer id;

  private String skuCode;

  private Date submitReviewTime;

  private BigDecimal newAverageLogisticsCosts;

  private BigDecimal newSalePrice;

  private BigDecimal newCostPrice;

  private Integer changeStatus;

  private String newNameCn;

  private Integer newBrandId;

  private String newWeight;

  private BigDecimal newNetWeight;

  private String newMaterial;

  private String newSpecification;

  private String newPurpose;

  private String newPlaceoforigin;

  private BigDecimal newExchangeCostPrice;

  private Long newSupplierId;

  private Integer newSkuType;

  private Long submitUserId;

  private BigDecimal newClearanceFee;
  private BigDecimal newTariff;

  private Integer newCategoryId;
  private String newCategoryFullName;
  private String newBu;
  private Integer newIsOwnImported;
  private Integer newCrossBorderFlag;
  private Integer newClearanceWay;
  private Boolean canWithdraw;
  private Integer preSubmitStatus;
  private Integer specialVariety;

  public String getSkuCode() {
    return skuCode;
  }

  public void setSkuCode(String skuCode) {
    this.skuCode = skuCode;
  }

  public Date getSubmitReviewTime() {
    return submitReviewTime;
  }

  public void setSubmitReviewTime(Date submitReviewTime) {
    this.submitReviewTime = submitReviewTime;
  }

  public BigDecimal getNewAverageLogisticsCosts() {
    return newAverageLogisticsCosts;
  }

  public void setNewAverageLogisticsCosts(BigDecimal newAverageLogisticsCosts) {
    this.newAverageLogisticsCosts = newAverageLogisticsCosts;
  }

  public BigDecimal getNewSalePrice() {
    return newSalePrice;
  }

  public void setNewSalePrice(BigDecimal newSalePrice) {
    this.newSalePrice = newSalePrice;
  }

  public BigDecimal getNewCostPrice() {
    return newCostPrice;
  }

  public void setNewCostPrice(BigDecimal newCostPrice) {
    this.newCostPrice = newCostPrice;
  }

  public Integer getChangeStatus() {
    return changeStatus;
  }

  public void setChangeStatus(Integer changeStatus) {
    this.changeStatus = changeStatus;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public String getNewNameCn() {
    return newNameCn;
  }

  public void setNewNameCn(String newNameCn) {
    this.newNameCn = newNameCn;
  }

  public Integer getNewBrandId() {
    return newBrandId;
  }

  public void setNewBrandId(Integer newBrandId) {
    this.newBrandId = newBrandId;
  }

  public String getNewWeight() {
    return newWeight;
  }

  public void setNewWeight(String newWeight) {
    this.newWeight = newWeight;
  }

  public BigDecimal getNewNetWeight() {
    return newNetWeight;
  }

  public void setNewNetWeight(BigDecimal newNetWeight) {
    this.newNetWeight = newNetWeight;
  }

  public String getNewMaterial() {
    return newMaterial;
  }

  public void setNewMaterial(String newMaterial) {
    this.newMaterial = newMaterial;
  }

  public String getNewSpecification() {
    return newSpecification;
  }

  public void setNewSpecification(String newSpecification) {
    this.newSpecification = newSpecification;
  }

  public String getNewPurpose() {
    return newPurpose;
  }

  public void setNewPurpose(String newPurpose) {
    this.newPurpose = newPurpose;
  }

  public String getNewPlaceoforigin() {
    return newPlaceoforigin;
  }

  public void setNewPlaceoforigin(String newPlaceoforigin) {
    this.newPlaceoforigin = newPlaceoforigin;
  }

  public BigDecimal getNewExchangeCostPrice() {
    return newExchangeCostPrice;
  }

  public void setNewExchangeCostPrice(BigDecimal newExchangeCostPrice) {
    this.newExchangeCostPrice = newExchangeCostPrice;
  }

  public Long getNewSupplierId() {
    return newSupplierId;
  }

  public void setNewSupplierId(Long newSupplierId) {
    this.newSupplierId = newSupplierId;
  }

  public Integer getNewSkuType() {
    return newSkuType;
  }

  public void setNewSkuType(Integer newSkuType) {
    this.newSkuType = newSkuType;
  }

  public Long getSubmitUserId() {
    return submitUserId;
  }

  public void setSubmitUserId(Long submitUserId) {
    this.submitUserId = submitUserId;
  }

  public BigDecimal getNewClearanceFee() {
    return newClearanceFee;
  }

  public void setNewClearanceFee(BigDecimal newClearanceFee) {
    this.newClearanceFee = newClearanceFee;
  }

  public BigDecimal getNewTariff() {
    return newTariff;
  }

  public void setNewTariff(BigDecimal newTariff) {
    this.newTariff = newTariff;
  }

  public Integer getNewCategoryId() {
    return newCategoryId;
  }

  public void setNewCategoryId(Integer newCategoryId) {
    this.newCategoryId = newCategoryId;
  }

  public String getNewBu() {
    return newBu;
  }

  public void setNewBu(String newBu) {
    this.newBu = newBu;
  }

  public Integer getNewIsOwnImported() {
    return newIsOwnImported;
  }

  public void setNewIsOwnImported(Integer newIsOwnImported) {
    this.newIsOwnImported = newIsOwnImported;
  }

  public Integer getNewCrossBorderFlag() {
    return newCrossBorderFlag;
  }

  public void setNewCrossBorderFlag(Integer newCrossBorderFlag) {
    this.newCrossBorderFlag = newCrossBorderFlag;
  }

  public Integer getNewClearanceWay() {
    return newClearanceWay;
  }

  public void setNewClearanceWay(Integer newClearanceWay) {
    this.newClearanceWay = newClearanceWay;
  }

  public Boolean getCanWithdraw() {
    return canWithdraw;
  }

  public void setCanWithdraw(Boolean canWithdraw) {
    this.canWithdraw = canWithdraw;
  }

  public Integer getPreSubmitStatus() {
    return preSubmitStatus;
  }

  public void setPreSubmitStatus(Integer preSubmitStatus) {
    this.preSubmitStatus = preSubmitStatus;
  }

    public String getNewCategoryFullName() {
        return newCategoryFullName;
    }

    public void setNewCategoryFullName(String newCategoryFullName) {
        this.newCategoryFullName = newCategoryFullName;
    }

  public Integer getSpecialVariety() {
    return specialVariety;
  }

  public void setSpecialVariety(Integer specialVariety) {
    this.specialVariety = specialVariety;
  }
}
